import asyncio

import aiohttp
from aiohttp_socks import ProxyConnector


async def main():
    connector = ProxyConnector.from_url("socks5://10.11.35.215:9050")
    async with aiohttp.ClientSession(
        connector=connector,
    ) as session:
        response = await session.get("https://www.google.com")
        print(response.status)
        print(await response.text())


if __name__ == "__main__":
    asyncio.run(main())



"""
model层基类

@Time : 2022/7/8 16:18
@Author : noHairMan
@File : base.py
@Project : nhm-spider
"""


# todo: 待增加不同类型的字段，增加字段`类型检查`或`自动转换`功能。
#       IntegerField, StringField, FloatField, JsonField ...
#       再深入可考虑`长度检查`等
class Field:
    def __init__(self):
        pass


class IntegerField(Field):
    pass



import asyncio
import time

from nhm_spider.common.log import get_logger
from nhm_spider.common.time_counter import time_limit
from nhm_spider.core.downloader import Downloader
from nhm_spider.core.scheduler import Scheduler
from nhm_spider.exceptions import SettingsError


class Engine:
    """
    todo: deprecated
    """

    def __init__(self):
        self.logger = get_logger(self.__class__.__name__)

    # 显示方法执行的时间
    @time_limit(display=True)
    def run(self, spider_class):
        spider = spider_class.from_crawler()

        downloader = Downloader(spider)
        scheduler = Scheduler(spider)

        run_forever = spider.settings.get_bool("RUN_FOREVER")
        if not isinstance(run_forever, bool):
            raise SettingsError(
                f"Settings param `RUN_FOREVER` must be boolean., got type {type(run_forever)}.",
            )
        if run_forever is True:
            run_loop_interval = spider.settings.get_int("RUN_LOOP_INTERVAL")
            while run_forever:
                asyncio.run(scheduler.crawl(spider, downloader))
                time.sleep(run_loop_interval)
        else:
            asyncio.run(scheduler.crawl(spider, downloader))

    def __del__(self):
        self.logger.info("Engine quit.")



from nhm_spider.crawler import CrawlerProcess
from nhm_spider.http import FormRequest, Request, Response
from nhm_spider.item.base import Item
from nhm_spider.item.field.base import Field
from nhm_spider.spider.base import Spider



from nhm_spider import CrawlerProcess, Field, Item, Request, Spider
from nhm_spider.pipeline import Pipeline


class MpItem(Item):
    page = Field()


class MpPipeline(Pipeline):
    async def process_item(self, item, spider):
        return item


class MpSpider(Spider):
    name = "MpSpider"
    custom_settings = {
        "USE_SESSION": True,
        "CLEAR_COOKIE": False,
        "CONCURRENT_REQUESTS": 4,
        "DEFAULT_REQUEST_HEADER": {
            "User-Agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) "
            "Chrome/83.0.4103.97 Safari/537.36",
        },
        "ENABLED_PIPELINE": [
            # MpPipeline,
        ],
        # "RUN_FOREVER": True,
        # "RUN_LOOP_INTERVAL": 5,
        "DEBUG": True,
    }

    def __init__(self):
        super().__init__()
        self.start_url = "http://www.mp.cc/search"
        self.page_url = "http://www.mp.cc/search/{}"

    async def start_request(self):
        request = Request(self.start_url, self.parse)
        yield request

    def parse(self, response):
        page_info = response.xpath('//a[@class="number"][last()]/text()').get("0")
        total_page = int(page_info)
        for page in range(1, total_page + 1):
            request = Request(self.page_url.format(page), self.parse_page)
            request.meta["page"] = page
            yield request

    def parse_page(self, response):
        item = MpItem({"page": response.meta["page"]})
        yield item


if __name__ == "__main__":
    process = CrawlerProcess()
    process.crawl(MpSpider)
    process.start()
